OC.L10N.register(
    "core",
    {
    "Please select a file." : "Veuillez sélectionner un fichier.",
    "File is too big" : "Le fichier est trop volumineux",
    "The selected file is not an image." : "Le fichier sélectionné n’est pas une image.",
    "The selected file cannot be read." : "Le fichier sélectionné ne peut pas être lu.",
    "The file was uploaded" : "Le fichier a été envoyé",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Le fichier envoyé dépasse la valeur upload_max_filesize spécifiée dans php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Le fichier envoyé dépasse la valeur MAX_FILE_SIZE spécifiée dans le formulaire HTML",
    "The file was only partially uploaded" : "Le fichier n’a été que partiellement envoyé",
    "No file was uploaded" : "Aucun fichier n’a été envoyé",
    "Missing a temporary folder" : "Absence de dossier temporaire",
    "Could not write file to disk" : "Impossible d’écrire le fichier sur le disque",
    "A PHP extension stopped the file upload" : "Une extension PHP a arrêté l’envoi du fichier",
    "Invalid file provided" : "Fichier non valide",
    "No image or file provided" : "Pas d’image ou fichier fourni",
    "Unknown filetype" : "Type de fichier inconnu",
    "An error occurred. Please contact your admin." : "Une erreur est survenue. Veuillez contacter un administrateur.",
    "Invalid image" : "Image invalide",
    "State token does not match" : "Les jetons de statut ne correspondent pas",
    "Invalid app password" : "Mot de passe d’application non valide",
    "Could not complete login" : "Impossible de terminer la connexion",
    "State token missing" : "Jeton d’état manquant",
    "Your login token is invalid or has expired" : "Votre jeton de connexion est invalide ou a expiré",
    "Please use original client" : "Veuillez utiliser le client d'origine",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Cette version communautaire de Nextcloud n’est pas prise en charge et les notifications push sont limitées.",
    "Login" : "S’identifier",
    "Unsupported email length (>255)" : "Longueur de l’e-mail non supportée (> 255 caractères)",
    "Password reset is disabled" : "La réinitialisation du mot de passe est désactivée",
    "Could not reset password because the token is expired" : "Impossible de réinitialiser le mot de passe car le jeton d’authentification est expiré",
    "Could not reset password because the token is invalid" : "Impossible de réinitialiser le mot de passe car le jeton d’authentification n’est pas valide",
    "Password is too long. Maximum allowed length is 469 characters." : "Le mot de passe est trop long. La longueur maximale autorisée est de 469 caractères.",
    "%s password reset" : "Réinitialisation de votre mot de passe %s",
    "Password reset" : "Réinitialiser le mot de passe",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquez sur le bouton suivant pour réinitialiser votre mot de passe. Si vous n’avez pas demandé cette réinitialisation de mot de passe, vous pouvez ignorer cet e-mail.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Cliquer sur le lien suivant pour réinitialiser votre mot de passe. Si vous n’avez pas demandé cette réinitialisation de mot de passe, alors ignorez cet e-mail.",
    "Reset your password" : "Réinitialiser votre mot de passe",
    "The given provider is not available" : "Le fournisseur indiqué n'est pas disponible",
    "Task not found" : "Tâche non trouvée",
    "Internal error" : "Erreur interne",
    "Not found" : "Non trouvé",
    "Node is locked" : "Le noeud est verrouillé",
    "Bad request" : "Requête erronée",
    "Requested task type does not exist" : "Le type de tâche demandé n’existe pas",
    "Necessary language model provider is not available" : "Le fournisseur de modèle de langage nécessaire n’est pas disponible",
    "No text to image provider is available" : "Aucun fournisseur de texte vers image n’est disponible",
    "Image not found" : "Image non trouvée",
    "No translation provider available" : "Aucun fournisseur de traduction n’est disponible",
    "Could not detect language" : "Impossible de détecter la langue",
    "Unable to translate" : "Impossible de traduire",
    "No valid filters provided" : "Aucun filtre valide fourni",
    "[%d / %d]: %s" : "[%d / %d] : %s",
    "Repair step:" : "Étape de réparation :",
    "Repair info:" : "Informations de réparation :",
    "Repair warning:" : "Avertissement de réparation :",
    "Repair error:" : "Erreur de réparation :",
    "Nextcloud Server" : "Serveur Nextcloud",
    "Some of your link shares have been removed" : "Certains de vos liens partagés ont été supprimés.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "En raison d’une faille de sécurité, nous avons supprimé certains de vos liens partagés. Consultez le lien ci-dessus pour plus d’informations.",
    "The account limit of this instance is reached." : "Le nombre maximum de comptes a été atteint sur cette instance.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Saisissez votre clé de licence dans l’application Support afin d’augmenter la limite de comptes. Cela vous donne également tous les avantages supplémentaires que Nextcloud Enterprise offre et est fortement recommandé pour l’exploitation dans les entreprises.",
    "Learn more ↗" : " En savoir plus ↗",
    "Preparing update" : "Préparation de la mise à jour",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Veuillez utiliser la mise à jour en ligne de commande, car la mise à jour via le navigateur est désactivée dans votre fichier config.php.",
    "Turned on maintenance mode" : "Mode de maintenance activé",
    "Turned off maintenance mode" : "Mode de maintenance désactivé",
    "Maintenance mode is kept active" : "Le mode de maintenance est laissé actif",
    "Updating database schema" : "Mise à jour du schéma de la base de données",
    "Updated database" : "Base de données mise à jour",
    "Update app \"%s\" from App Store" : "Mise à jour l’application « %s » depuis le magasin d’applications",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Vérification de la possibilité de mettre à jour le schéma de la base de données pour %s (cela peut prendre un certain temps selon la taille de la base de données)",
    "Updated \"%1$s\" to %2$s" : "Mise à jour de « %1$s » vers %2$s",
    "Set log level to debug" : "Définir le niveau de journalisation sur débogage",
    "Reset log level" : "Réinitialiser le niveau de journalisation",
    "Starting code integrity check" : "Lancement de la vérification d’intégrité du code",
    "Finished code integrity check" : "Fin de la vérification d’intégrité du code",
    "%s (incompatible)" : "%s (incompatible)",
    "The following apps have been disabled: %s" : "Les applications suivantes ont été désactivées : %s",
    "Already up to date" : "Déjà à jour",
    "Windows Command Script" : "Script de commande Windows",
    "Electronic book document" : "Livre électronique",
    "TrueType Font Collection" : "Collection de police TrueType",
    "Web Open Font Format" : "Format Web Open Font",
    "GPX geographic data" : "Données géographiques GPX",
    "Gzip archive" : "Archive Gzip",
    "Adobe Illustrator document" : "Document Adobe Illustrator",
    "Java source code" : "Code source Java",
    "JavaScript source code" : "Code source Javascript",
    "JSON document" : "Document JSON",
    "Microsoft Access database" : "Base de données Microsoft Access",
    "Microsoft OneNote document" : "Document Microsoft One Note",
    "Microsoft Word document" : "Document Microsoft Word",
    "Unknown" : "Inconnu",
    "PDF document" : "Document PDF",
    "PostScript document" : "Document PostScript",
    "RSS summary" : "Résumé RSS",
    "Android package" : "Paquet Android",
    "KML geographic data" : "Données géographiques KML",
    "KML geographic compressed data" : "Données géographiques compressées KML",
    "Lotus Word Pro document" : "Document Lotus Word Pro",
    "Excel spreadsheet" : "Feuille de calcul Excel",
    "Excel add-in" : "Extension Excel",
    "Excel 2007 binary spreadsheet" : "Feuille de calcul binaire Excel 2007",
    "Excel spreadsheet template" : "Modèle de feuille de calcul Excel",
    "Outlook Message" : "Message Outlook",
    "PowerPoint presentation" : "Présentation Powerpoint",
    "PowerPoint add-in" : "Extension PowerPoint",
    "PowerPoint presentation template" : "Modèle de présentation PowerPoint",
    "Word document" : "Document Word",
    "ODF formula" : "Formule ODF",
    "ODG drawing" : "Dessin ODG",
    "ODG drawing (Flat XML)" : "Dessin ODG (Flat XML)",
    "ODG template" : "Modèle ODG",
    "ODP presentation" : "Présentation ODP",
    "ODP presentation (Flat XML)" : "Présentation ODP (Flat XML)",
    "ODP template" : "Modèle ODP",
    "ODS spreadsheet" : "Feuille de calcul ODS",
    "ODS spreadsheet (Flat XML)" : "Feuille de calcul ODS (Flat XML)",
    "ODS template" : "Modèle ODS",
    "ODT document" : "Document ODT",
    "ODT document (Flat XML)" : "Document ODF (Flat XML)",
    "ODT template" : "Modèle ODT",
    "PowerPoint 2007 presentation" : "Présentation PowerPoint 2007",
    "PowerPoint 2007 show" : "Diaporama PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Modèle de présentation PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Feuille de calcul Excel 2007",
    "Excel 2007 spreadsheet template" : "Modèle de feuille de calcul Excel 2007",
    "Word 2007 document" : "Document Word 2007",
    "Word 2007 document template" : "Modèle de document Word 2007",
    "Microsoft Visio document" : "Document Microsoft Visio",
    "WordPerfect document" : "Document WordPerfect",
    "7-zip archive" : "Archive 7-zip",
    "Blender scene" : "Scène Blender",
    "Bzip2 archive" : "Archive Bzip2",
    "Debian package" : "Paquet Debian",
    "FictionBook document" : "Document FictionBook",
    "Unknown font" : "Police de caractère inconnue",
    "Krita document" : "Document Krita",
    "Mobipocket e-book" : "Livre électronique Mobipocket",
    "Windows Installer package" : "Paquet d'installation Windows",
    "Perl script" : "Script Perl",
    "PHP script" : "Script PHP",
    "Tar archive" : "Archive Tar",
    "XML document" : "Document XML",
    "YAML document" : "Document YAML",
    "Zip archive" : "Archive Zip",
    "Zstandard archive" : "Archive Zstandard",
    "AAC audio" : "Fichier audio AAC",
    "FLAC audio" : "Fichier audio FLAC",
    "MPEG-4 audio" : "Fichier audio MPEG-4",
    "MP3 audio" : "Fichier audio MP3",
    "Ogg audio" : "Fichier audio Ogg",
    "RIFF/WAVe standard Audio" : "Fichier audio standard RIFF/WAVe",
    "WebM audio" : "Fichier audio WebM",
    "MP3 ShoutCast playlist" : "Liste de lecture ShoutCast MP3",
    "Windows BMP image" : "Image Windows BMP",
    "Better Portable Graphics image" : "Image Better Portable Graphics",
    "EMF image" : "Image EMF",
    "GIF image" : "Image GIF",
    "HEIC image" : "Image HEIC",
    "HEIF image" : "Image HEIF",
    "JPEG-2000 JP2 image" : "Image JPEG-2000 JP2",
    "JPEG image" : "Image JPEG",
    "PNG image" : "Image PNG",
    "SVG image" : "Image SVG",
    "Truevision Targa image" : "Image Truevision Targa",
    "TIFF image" : "Image TIFF",
    "WebP image" : "Image WebP",
    "Digital raw image" : "Image Digital raw",
    "Windows Icon" : "Icône Windows",
    "Email message" : "E-mail",
    "VCS/ICS calendar" : "Calendrier VCS/ICS",
    "CSS stylesheet" : "Feuille de style CSS",
    "CSV document" : "Document CSV",
    "HTML document" : "Document HTML",
    "Markdown document" : "Document Markdown",
    "Org-mode file" : "Fichier Org-mode",
    "Plain text document" : "Document texte brut",
    "Rich Text document" : "Document texte enrichi",
    "Electronic business card" : "Carte de visite électronique",
    "C++ source code" : "Code source C++",
    "LDIF address book" : "Carnet d'adresses LDIF",
    "NFO document" : "Document NFO",
    "PHP source" : "Code source PHP",
    "Python script" : "Script Python",
    "ReStructuredText document" : "Document ReStructuredText",
    "3GPP multimedia file" : "Fichier multimédia 3GPP",
    "MPEG video" : "Vidéo MPEG",
    "DV video" : "Vidéo DV",
    "MPEG-2 transport stream" : "Flux de transport MPEG-2",
    "MPEG-4 video" : "Vidéo MPEG-4",
    "Ogg video" : "Vidéo OGG",
    "QuickTime video" : "Vidéo QuickTime",
    "WebM video" : "Vidéo WebM",
    "Flash video" : "Vidéo Flash",
    "Matroska video" : "Vidéo Matroska",
    "Windows Media video" : "Vidéo Windows Media",
    "AVI video" : "Vidéo AVI",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "La mise à jour est en cours, quitter la page peut interrompre le processus dans de nombreux environnements.",
    "Update to {version}" : "Mettre à jour vers {version}",
    "An error occurred." : "Une erreur est survenue.",
    "Please reload the page." : "Veuillez recharger la page.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "La mise à jour a échoué. Pour plus d’informations <a href=\"{url}\">consultez notre publication sur le forum</a> à propos de ce problème.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La mise à jour a échoué. Veuillez reporter le problème à la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">communauté Nextcloud</a>.",
    "Continue to {productName}" : "Continuer vers {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes.","La mise à jour est terminée. Vous allez être redirigé vers {productName} dans %n secondes."],
    "Applications menu" : "Menu des applications",
    "Apps" : "Applications",
    "More apps" : "Plus d’applications",
    "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications","{count} notifications"],
    "No" : "Non",
    "Yes" : "Oui",
    "The remote URL must include the user." : "L'URL distante doit inclure l'utilisateur.",
    "Invalid remote URL." : "URL distante invalide.",
    "Failed to add the public link to your Nextcloud" : "Impossible d'ajouter le lien public à votre Nextcloud",
    "Federated user" : "Utilisateur fédéré",
    "user@your-nextcloud.org" : "utilisateur@votre-nextcloud.org",
    "Create share" : "Créer un partage",
    "Direct link copied" : "Lien direct copié",
    "Please copy the link manually:" : "Veuillez copier le lien manuellement :",
    "Custom date range" : "Plage de dates personnalisée",
    "Pick start date" : "Sélectionner une date de début",
    "Pick end date" : "Sélectionner une date de fin",
    "Search in date range" : "Rechercher dans la plage de dates",
    "Search in current app" : "Recherche dans l'application courante",
    "Clear search" : "Effacer la recherche",
    "Search everywhere" : "Chercher partout",
    "Start typing to search" : "Commencez à taper pour lancer la recherche",
    "No matching results" : "Aucun résultat correspondant",
    "Today" : "Aujourd’hui",
    "Last 7 days" : "7 derniers jours",
    "Last 30 days" : "30 derniers jours",
    "This year" : "Cette année",
    "Last year" : "Année dernière",
    "Between {startDate} and {endDate}" : "Entre le {startDate} et le {endDate}",
    "Unified search" : "Recherche unifiée",
    "Search apps, files, tags, messages" : "Rechercher des applications, des fichiers, des étiquettes, des messages",
    "Places" : "Emplacements",
    "Date" : "Date",
    "Search people" : "Rechercher des personnes",
    "People" : "Personnes",
    "Filter in current view" : "Filtrer dans la vue actuelle",
    "Search connected services" : "Services connectés de recherche",
    "Results" : "Résultats",
    "Load more results" : "Charger plus de résultats",
    "Search in" : "Rechercher dans",
    "Log in" : "Se connecter",
    "Logging in …" : "Connexion en cours…",
    "Log in to {productName}" : "Se connecter à {productName}",
    "Wrong login or password." : "Mauvais identifiant ou mot de passe.",
    "This account is disabled" : "Ce compte est désactivé",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Nous avons détecté plusieurs tentatives de connexion invalides depuis votre adresse IP. C’est pourquoi votre prochaine connexion sera retardée de 30 secondes.",
    "Account name or email" : "Nom d’utilisateur ou adresse e-mail",
    "Account name" : "Nom du compte",
    "Server side authentication failed!" : "L’authentification sur le serveur a échoué !",
    "Please contact your administrator." : "Veuillez contacter votre administrateur.",
    "Session error" : "Erreur de session",
    "It appears your session token has expired, please refresh the page and try again." : "Il semblerait que votre jeton de session ait expiré, veuillez rafraîchir la page et essayer à nouveau.",
    "An internal error occurred." : "Une erreur interne est survenue.",
    "Please try again or contact your administrator." : "Veuillez réessayer ou contactez votre administrateur.",
    "Password" : "Mot de passe",
    "Log in with a device" : "Se connecter avec un périphérique",
    "Login or email" : "Identifiant ou e-mail",
    "Your account is not setup for passwordless login." : "Votre compte n’est pas paramétré pour une authentification sans mot de passe.",
    "Your connection is not secure" : "Votre connexion n’est pas sécurisée",
    "Passwordless authentication is only available over a secure connection." : "L’authentification sans mot de passe n’est possible qu’au travers d’une connexion sécurisée.",
    "Browser not supported" : "Navigateur non compatible",
    "Passwordless authentication is not supported in your browser." : "L’authentification sans mot de passe n’est pas supportée par votre navigateur.",
    "Reset password" : "Réinitialiser le mot de passe",
    "Back to login" : "Retour à la page de connexion",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Si ce compte existe, un message de réinitialisation de mot de passe a été envoyé à l’adresse e-mail correspondante. Si vous ne le recevez pas, veuillez vérifier l’identifiant/adresse e-mail, vérifiez dans votre dossier d’indésirables ou demandez de l’aide à l’administrateur de cette instance.",
    "Couldn't send reset email. Please contact your administrator." : "Impossible d’envoyer l'e-mail de réinitialisation. Veuillez contacter votre administrateur.",
    "Password cannot be changed. Please contact your administrator." : "Le mot de passe ne pas être modifié. Veuillez contacter votre administrateur.",
    "New password" : "Nouveau mot de passe",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Vos fichiers sont chiffrés. Il n’y aura aucun moyen de récupérer vos données après la réinitialisation de votre mot de passe. Si vous n’êtes pas sûr de ce que vous faîtes, veuillez contacter votre administrateur avant de continuer. Voulez-vous vraiment continuer ?",
    "I know what I'm doing" : "Je sais ce que je fais",
    "Resetting password" : "Réinitialisation du mot de passe",
    "Schedule work & meetings, synced with all your devices." : "Planifiez votre travail et des réunions, synchronisées avec tous vos appareils.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Gardez les contacts de vos collègues et amis au même endroit sans divulguer leurs informations personnelles.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Application de messagerie électronique simple et bien intégrée avec Fichiers, Contacts et Calendrier.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Messagerie instantanée, appels vidéo, partage d'écran, réunion en ligne et web conférences - dans votre navigateur et avec des applications mobiles.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documents, feuilles de calculs ou présentations créées sur Collabora Online.",
    "Distraction free note taking app." : "Application de prise de notes sans distraction.",
    "Recommended apps" : "Applications recommandées",
    "Could not fetch list of apps from the App Store." : "Impossible de récupérer la liste des applications depuis le magasin d’applications",
    "App download or installation failed" : "Échec lors du téléchargement ou de l’installation de l’application",
    "Cannot install this app because it is not compatible" : "Impossible d’installer cette app parce qu’elle n’est pas compatible",
    "Cannot install this app" : "Impossible d’installer cette app",
    "Skip" : "Ignorer",
    "Install recommended apps" : "Installer les applications recommandées",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Menu des paramètres",
    "Search contacts" : "Rechercher des contacts",
    "Reset search" : "Réinitialiser la recherche",
    "Could not load your contacts" : "Impossible de charger vos contacts",
    "No contacts found" : "Aucun contact trouvé",
    "Show all contacts" : "Afficher tous les contacts",
    "Install the Contacts app" : "Installer l’appli Contacts",
    "Search" : "Rechercher",
    "No results for {query}" : "Aucun résultat pour {query}",
    "Press Enter to start searching" : "Appuyer sur Entrée pour démarrer la recherche",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Veuillez saisir au moins {minSearchLength} caractère pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche","Veuillez saisir au moins {minSearchLength} caractères pour lancer la recherche"],
    "An error occurred while searching for {type}" : "Une erreur est survenue lors de la recherche de {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "La recherche démarre dès que vous commencez à taper et les résultats peuvent être atteints avec les flèches du clavier",
    "Search for {name} only" : "Rechercher pour {name} uniquement",
    "Forgot password?" : "Mot de passe oublié ?",
    "Back to login form" : "Retour au formulaire de connexion",
    "Back" : "Retour",
    "Login form is disabled." : "Le formulaire de connexion est désactivé.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Le formulaire de connexion Nextcloud est désactivé. Utilisez une autre option de connexion si disponible ou contactez un administrateur.",
    "More actions" : "Plus d'actions",
    "User menu" : "Menu utilisateur",
    "Your guest name: {user}" : "Votre nom d'invité : {user}",
    "You are currently not identified." : "Vous n'êtes actuellement pas identifié.",
    "Set public name" : "Définir le nom public",
    "Change public name" : "Changer le nom public",
    "Password is too weak" : "Mot de passe trop faible",
    "Password is weak" : "Mot de passe faible",
    "Password is average" : "Mot de passe moyen",
    "Password is strong" : "Mot de passe fort",
    "Password is very strong" : "Mot de passe très fort",
    "Password is extremely strong" : "Mot de passe extrêmement fort",
    "Unknown password strength" : "Sécurité du mot de passe inconnue",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Votre répertoire de données est certainement accessible depuis Internet car le fichier <code>.htaccess</code> ne fonctionne pas.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Pour savoir comment configurer correctement votre serveur, veuillez lire la {linkStart}documentation{linkEnd}.",
    "Autoconfig file detected" : "Fichier de configuration automatique détecté",
    "The setup form below is pre-filled with the values from the config file." : "Le formulaire de configuration ci-dessous est pré-rempli avec les valeurs du fichier de configuration.",
    "Security warning" : "Avertissement de sécurité",
    "Create administration account" : "Créer un compte administrateur",
    "Administration account name" : "Nom du compte administrateur",
    "Administration account password" : "Mot de passe du compte administrateur",
    "Storage & database" : "Stockage & base de données",
    "Data folder" : "Répertoire des données",
    "Database configuration" : "Configuration de la base de données",
    "Only {firstAndOnlyDatabase} is available." : "Seul(e) {firstAndOnlyDatabase} est disponible.",
    "Install and activate additional PHP modules to choose other database types." : "Installez et activez les modules PHP additionnels adéquats pour choisir d’autres types de base de données.",
    "For more details check out the documentation." : "Consultez la documentation pour plus de détails.",
    "Performance warning" : "Avertissement à propos des performances",
    "You chose SQLite as database." : "Vous avez choisi SQLite comme base de données. ",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite ne devrait être utilisée que pour des instances minimales ou de développement. Pour une instance de production, nous recommandons une infrastructure de base de données différente. ",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si vous utilisez des clients de synchronisation de fichiers, l’utilisation de SQLite est fortement découragée. ",
    "Database user" : "Utilisateur de la base de données",
    "Database password" : "Mot de passe de la base de données",
    "Database name" : "Nom de la base de données",
    "Database tablespace" : "Espace de stockage de la base de données",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Veuillez spécifier le numéro du port avec le nom de l’hôte (par exemple, localhost:5432).",
    "Database host" : "Hôte de la base de données",
    "localhost" : "localhost",
    "Install" : "Installer",
    "Need help?" : "Besoin d’aide ?",
    "See the documentation" : "Lire la documentation",
    "{name} version {version} and above" : "{name} version {version} et supérieure",
    "This browser is not supported" : "Ce navigateur n'est pas supporté",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Votre navigateur n'est pas pris en charge. Veuillez passer à une version plus récente ou à un navigateur supporté.",
    "Continue with this unsupported browser" : "Continuer avec ce navigateur non pris en charge",
    "Supported versions" : "Versions supportées",
    "Choose {file}" : "Choisir {file}",
    "Choose" : "Choisir",
    "Copy to {target}" : "Copier vers {target}",
    "Copy" : "Copier",
    "Move to {target}" : "Déplacer vers {target}",
    "Move" : "Déplacer",
    "OK" : "OK",
    "read-only" : "Lecture seule",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} fichier en conflit","{count} fichiers en conflit","{count} fichiers en conflit"],
    "One file conflict" : "Un conflit de fichier",
    "New Files" : "Nouveaux fichiers",
    "Already existing files" : "Fichiers déjà existants",
    "Which files do you want to keep?" : "Quels fichiers souhaitez-vous conserver ?",
    "If you select both versions, the copied file will have a number added to its name." : "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
    "Cancel" : "Annuler",
    "Continue" : "Continuer",
    "(all selected)" : "(tous sélectionnés)",
    "({count} selected)" : "({count} sélectionné(s))",
    "Error loading file exists template" : "Erreur lors du chargement du modèle de fichier existant",
    "Saving …" : "Enregistrement  …",
    "seconds ago" : "Il y a quelques secondes",
    "Connection to server lost" : "La connexion au serveur a été perdue",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problème de chargement de la page, actualisation dans %n seconde","Problème de chargement de la page, actualisation dans %n secondes","Problème de chargement de la page, actualisation dans %n secondes"],
    "Add to a project" : "Ajouter à un projet",
    "Show details" : "Afficher les détails",
    "Hide details" : "Masquer les détails",
    "Rename project" : "Renommer le projet",
    "Failed to rename the project" : "Impossible de renommer le projet",
    "Failed to create a project" : "Impossible de créer un projet",
    "Failed to add the item to the project" : "Impossible d'ajouter l'élément au projet",
    "Connect items to a project to make them easier to find" : "Reliez des éléments à un projet pour les retrouver plus facilement",
    "Type to search for existing projects" : "Saisissez du texte pour rechercher un projet existant",
    "New in" : "Nouveau dans",
    "View changelog" : "Voir le journal des modifications",
    "Close \"{dialogTitle}\" dialog" : "Fermer la boîte de dialogue « {dialogTitle} »",
    "Email length is at max (255)" : "La longueur de l'e-mail est au maximum (255)",
    "Clipboard not available, please copy manually" : "Le presse-papier n'est pas disponible, veuillez copier manuellement",
    "Personal" : "Personnel",
    "Accounts" : "Comptes",
    "Admin" : "Administration",
    "Help" : "Aide",
    "Access forbidden" : "Accès non autorisé",
    "You are not allowed to access this page." : "Vous n'êtes pas autorisé à accéder à cette page.",
    "Back to %s" : "Retour à %s",
    "Page not found" : "Page non trouvée",
    "The page could not be found on the server or you may not be allowed to view it." : "La page n'a pas pu être trouvée sur le serveur ou vous n'avez pas le droit de la visualiser.",
    "Too many requests" : "Trop de requêtes",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Il y a trop de requêtes depuis votre réseau. Réessayez plus tard ou contactez votre administrateur s'il s'agit d'une erreur.",
    "Error" : "Erreur",
    "Internal Server Error" : "Erreur interne du serveur",
    "The server was unable to complete your request." : "Le serveur est incapable d'exécuter votre requête.",
    "If this happens again, please send the technical details below to the server administrator." : "Si cela se reproduit, veuillez envoyer les détails techniques ci-dessous à l'administrateur du serveur.",
    "More details can be found in the server log." : "Le fichier log du serveur peut fournir plus de renseignements.",
    "For more details see the documentation ↗." : "Pour plus de détails, voir la documentation ↗.",
    "Technical details" : "Renseignements techniques",
    "Remote Address: %s" : "Adresse distante : %s",
    "Request ID: %s" : "ID de la demande : %s",
    "Type: %s" : "Type : %s",
    "Code: %s" : "Code : %s",
    "Message: %s" : "Message : %s",
    "File: %s" : "Fichier : %s",
    "Line: %s" : "Ligne : %s",
    "Trace" : "Trace",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "On dirait que vous essayez de réinstaller votre Nextcloud. Toutefois, le fichier CAN_INSTALL est absent de votre répertoire de configuration. Veuillez créer le fichier CAN_INSTALL dans votre dossier de configuration pour continuer.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Impossible de supprimer CAN_INSTALL du dossier de configuration. Veuillez supprimer ce fichier manuellement.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Cette application requiert JavaScript pour fonctionner correctement. Veuillez {linkstart}activer JavaScript{linkend} et recharger la page.",
    "Skip to main content" : "Passer au contenu principal",
    "Skip to navigation of app" : "Passer à la navigation d'application",
    "Go to %s" : "Aller à %s",
    "Get your own free account" : "Obtenez votre compte personnel gratuit",
    "Connect to your account" : "Connectez-vous à votre compte",
    "Please log in before granting %1$s access to your %2$s account." : "Veuillez vous connecter avant d'autoriser %1$s à accéder à votre compte %2$s.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Si vous n'essayez pas d'ajouter un nouveau périphérique ou une nouvelle application, quelqu'un fait une tentative d'accès à vos données. Dans ce cas, ne continuez pas et contactez votre administrateur système.",
    "App password" : "Mot de passe d'application",
    "Grant access" : "Autoriser l'accès",
    "Alternative log in using app password" : "Connexion à l'aide d'un mot de passe d'application",
    "Account access" : "Accès au compte",
    "Currently logged in as %1$s (%2$s)." : "Connecté en tant que %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Vous êtes sur le point d’accorder à « %1$s » l’accès à votre compte « %2$s ».",
    "Account connected" : "Compte connecté",
    "Your client should now be connected!" : "Votre client devrait maintenant être connecté !",
    "You can close this window." : "Vous pouvez fermer cette fenêtre.",
    "Previous" : "Précédent",
    "This share is password-protected" : "Ce partage est protégé par mot de passe",
    "The password is wrong or expired. Please try again or request a new one." : "Le mot de passe est incorrect ou expiré. Ré-essayez ou demandez-en un nouveau.",
    "Please type in your email address to request a temporary password" : "Veuillez saisir votre adresse e-mail pour recevoir un mot de passe temporaire",
    "Email address" : "Adresse e-mail",
    "Password sent!" : "Mot de passe envoyé !",
    "You are not authorized to request a password for this share" : "Vous n'êtes pas autorisé à demander un mot de passe pour ce partage",
    "Two-factor authentication" : "Authentification à double facteur",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "La sécurité renforcée est activée pour votre compte. Choisissez un second facteur pour l'authentification :",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Impossible de charger au moins l'une de vos méthodes activées d'authentification à deux facteurs . Veuillez contacter votre administrateur.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "L'authentification en deux étapes a été imposée mais n'est pas configurée sur votre compte. Contactez votre administrateur pour avoir de l'aide.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "L'authentification à deux facteurs est appliquée mais n'a pas été configurée sur votre compte. Veuillez continuer à configurer l'authentification à deux facteurs.",
    "Set up two-factor authentication" : "Paramétrer l'authentification à double facteur",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "L'authentification en deux étapes a été imposée mais n'est pas configurée sur votre compte. Utilisez un de vos codes de secours pour vous connecter ou contactez votre administrateur pour avoir de l'aide.",
    "Use backup code" : "Utiliser un code de récupération",
    "Cancel login" : "Annuler la connexion",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "La sécurité renforcée est appliquée à votre compte. Choisissez le fournisseur à configurer :",
    "Error while validating your second factor" : "Erreur lors de la validation de votre second facteur",
    "Access through untrusted domain" : "Accès à partir d'un domaine non approuvé",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Veuillez contacter votre administrateur. Si vous êtes un administrateur, modifiez la variable « trusted_domains » dans le fichier config/config.php comme l’exemple dans le fichier config/config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Vous trouverez d'autres informations sur la configuration dans la %1$sdocumentation %2$s.",
    "App update required" : "Mise à jour de l’application nécessaire",
    "%1$s will be updated to version %2$s" : "%1$s sera mis à jour vers la version %2$s",
    "The following apps will be updated:" : "Les applications suivantes vont être mises à jour :",
    "These incompatible apps will be disabled:" : "Ces applications incompatibles ont été désactivées :",
    "The theme %s has been disabled." : "Le thème %s a été désactivé.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Veuillez vous assurer qu’une copie de sauvegarde de la base de données, du dossier de configuration (config) et du dossier de données (data) a été réalisée avant de commencer.",
    "Start update" : "Démarrer la mise à jour",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Afin d'éviter les délais d'expiration avec les installations de volume conséquent, vous pouvez exécuter la commande suivante depuis le répertoire d'installation :",
    "Detailed logs" : "Logs détaillés",
    "Update needed" : "Mise à jour nécessaire",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Veuillez utiliser la mise à jour en ligne de commande car votre instance est volumineuse avec plus de 50 comptes.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Pour obtenir de l'aide, lisez la <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Je sais que si je continue à faire la mise à jour via le navigateur web, il existe le risque que la requête se heurte à un délai d'expiration et peut causer une perte de données, mais j'ai une copie de sauvegarde et je sais comment restaurer mon instance en cas d'échec.",
    "Upgrade via web on my own risk" : "Mettre à jour via le navigateur web à mes propres risques",
    "Maintenance mode" : "Mode maintenance",
    "This %s instance is currently in maintenance mode, which may take a while." : "Cette instance de %s est en cours de maintenance, cela peut prendre du temps.",
    "This page will refresh itself when the instance is available again." : "Cette page se rafraîchira d'elle-même lorsque le serveur sera de nouveau disponible.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Veuillez contacter votre administrateur système si ce message persiste ou apparaît de façon inattendue.",
    "Error occurred while checking server setup" : "Une erreur est survenue lors de la vérification de la configuration du serveur",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Pour plus d’information, voir la {linkstart}documentation ↗{linkend}.",
    "unknown text" : "texte inconnu",
    "Hello world!" : "Hello world!",
    "sunny" : "ensoleillé",
    "Hello {name}, the weather is {weather}" : "Bonjour {name}, le temps est {weather}",
    "Hello {name}" : "Bonjour {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Voici les résultats de votre recherche<script>alert(1)</script></strong>",
    "new" : "nouveau ",
    "_download %n file_::_download %n files_" : ["télécharger %n fichier","télécharger %n fichiers","télécharger %n fichiers"],
    "Searching …" : "Recherche…",
    "Logging in …" : "Connexion…",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Discussions, appels vidéo, partage d’écran, réunions en ligne et conférences web – depuis votre navigateur et les applications mobiles.",
    "Loading apps …" : "Chargement des applis…",
    "Installing apps …" : "Installation des applis en cours...",
    "Loading your contacts …" : "Chargement de vos contacts...",
    "Looking for {term} …" : "Recherche de {term} ...",
    "Search contacts …" : "Rechercher un contact...",
    "Loading more results …" : "Chargement de plus de résultats …",
    "You have not added any info yet" : "Vous n’avez pas ajouté d’informations pour le moment",
    "{user} has not added any info yet" : "{user} n’a pas ajouté d’informations pour le moment",
    "Error opening the user status modal, try hard refreshing the page" : "Erreur lors de l'ouverture du modal du statut de l'utilisateur, essayez d'actualiser la page",
    "Edit Profile" : "Modifier le profil",
    "The headline and about sections will show up here" : "Le titre et la section « À propos » apparaîtront ici",
    "Search {types} …" : "Rechercher {types}…",
    "Saving …" : "Enregistrement...",
    "Very weak password" : "Mot de passe très faible",
    "Weak password" : "Mot de passe faible",
    "So-so password" : "Mot de passe tout juste acceptable",
    "Good password" : "Mot de passe de sécurité suffisante",
    "Strong password" : "Mot de passe fort",
    "No action available" : "Aucune action disponible",
    "Error fetching contact actions" : "Erreur lors de la recherche d'actions de contact",
    "Non-existing tag #{tag}" : "Étiquette #{tag} inexistante",
    "Restricted" : "Restreint",
    "Invisible" : "Invisible",
    "Delete" : "Supprimer",
    "Rename" : "Renommer",
    "Collaborative tags" : "Étiquettes collaboratives ",
    "No tags found" : "Aucune étiquette n’a été trouvée",
    "Profile not found" : "Profile introuvable",
    "The profile does not exist." : "Le profile n'existe pas.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Votre répertoire de données est certainement accessible depuis internet car le fichier .htaccess ne fonctionne pas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Pour les informations de configuration de votre serveur, veuillez lire la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>.",
    "<strong>Create an admin account</strong>" : "<strong>Créer un compte administrateur</strong>",
    "New admin account name" : "Nouveau nom de compte administrateur",
    "New admin password" : "Nouveau mot de passe administrateur",
    "Show password" : "Afficher le mot de passe",
    "Toggle password visibility" : "Activer/Désactiver la visibilité du mot de passe",
    "Configure the database" : "Configurer la base de données",
    "Only %s is available." : "Seul(e) %s est disponible.",
    "Database account" : "Compte de base de données",
    "Installing …" : "Installation...",
    "Direct link copied to clipboard" : "Lien direct copié dans le presse-papiers"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
